@@ -10,13 +10,13 @@ LESS="less"
 DIFF="diff"
 #DIFF=/home/ivano/myprojs/numdiff/tests/Numdiff
 NUMDIFF="numdiff"
-#NUMDIFF="/home/ivano/myprojs/numdiff/numdiff"
+#NUMDIFF="/home/ivano/myprojs/numdiff-5.2.0/numdiff"
 
 echo "Viewer: $LESS"
 echo "Tester program: $DIFF"
 echo "Numdiff: $NUMDIFF"
 
-TESTS="test1 test2 test3 test4 test5 test6 test7 test8 test9 test10 test11 test12 test13 test14 test15 test16 test17 test18 test19 test20 test21 test22"
+TESTS="test1 test2 test3 test4 test5 test6 test7 test8 test9 test10 test11 test12 test13 test14 test15 test16 test17 test18 test19 test20 test21 test22 test23"
 
 for TEST in $TESTS
 do
